@@ -8,11 +8,11 @@ res.login()
 # Enable verbose logging to standard output
 resdk.start_logging()
 
-res.data.all()
+res.data.count()
 
-res.data.filter(type='data:genome')
+res.data.filter(type='data:index').count()
 
-res.data.filter(type='data:genome:fasta')
+res.data.filter(type="data:index:star", name__contains="Homo sapiens")
 
 # Get data object by slug
 genome_index = res.data.get('resdk-example-genome-index')
@@ -37,7 +37,7 @@ bam = res.run(
 
 bam.status
 
-# Get the latest meta data from the server
+# Get the latest info about the object from the server
 bam.update()
 bam.status
 
