@@ -36,24 +36,6 @@ from resdk.utils.table_cache import (
     save_pickle,
 )
 
-SAMPLE_FIELDS = [
-    "id",
-    "slug",
-    "name",
-    "descriptor",
-    "descriptor_schema",
-]
-DATA_FIELDS = [
-    "id",
-    "slug",
-    "modified",
-    "entity__name",
-    "entity__id",
-    "output",
-    "process__output_schema",
-    "process__slug",
-]
-
 # See _download_data function for in-depth explanation of this.
 EXP_ASYNC_CHUNK_SIZE = 50
 
@@ -80,6 +62,24 @@ class BaseTables(abc.ABC):
     META = "meta"
     QC = "qc"
 
+    SAMPLE_FIELDS = [
+        "id",
+        "slug",
+        "name",
+        "descriptor",
+        "descriptor_schema",
+    ]
+    DATA_FIELDS = [
+        "id",
+        "slug",
+        "modified",
+        "entity__name",
+        "entity__id",
+        "output",
+        "process__output_schema",
+        "process__slug",
+    ]
+
     def __init__(
         self,
         collection: Collection,
@@ -142,7 +142,7 @@ class BaseTables(abc.ABC):
         """
         sample_ids = set([d.sample.id for d in self._data])
 
-        query = self.collection.samples.filter(fields=SAMPLE_FIELDS)
+        query = self.collection.samples.filter(fields=self.SAMPLE_FIELDS)
         return [s for s in query if s.id in sample_ids]
 
     @property
@@ -172,7 +172,10 @@ class BaseTables(abc.ABC):
         data = []
         sample_ids, repeated_sample_ids = set(), set()
         for datum in self.collection.data.filter(
-            type=self.process_type, ordering="-created", fields=DATA_FIELDS
+            type=self.process_type,
+            status="OK",
+            ordering="-created",
+            fields=self.DATA_FIELDS,
         ):
             if datum.sample.id in sample_ids:
                 repeated_sample_ids.add(datum.sample.id)
@@ -301,10 +304,17 @@ class BaseTables(abc.ABC):
             save_pickle(data, self._cache_file(data_type))
         return data
 
-    @abc.abstractmethod
     def _cache_file(self, data_type: str) -> str:
         """Return full cache file path."""
-        pass
+        if data_type == self.META:
+            version = self._metadata_version
+        elif data_type == self.QC:
+            version = self._qc_version
+        else:
+            version = self._data_version
+
+        cache_file = f"{self.collection.slug}_{data_type}_{version}.pickle"
+        return os.path.join(self.cache_dir, cache_file)
 
     def _get_descriptors(self) -> pd.DataFrame:
         descriptors = []
@@ -370,9 +380,9 @@ class BaseTables(abc.ABC):
     @lru_cache()
     def _get_orange_object(self) -> Data:
         return self.collection.data.get(
-            process__slug="upload-orange-metadata",
+            type="data:metadata:unique",
             ordering="-modified",
-            fields=DATA_FIELDS,
+            fields=self.DATA_FIELDS,
             limit=1,
         )
 
@@ -402,17 +412,31 @@ class BaseTables(abc.ABC):
                 # TODO: logging, warning?
                 return pd.DataFrame()
 
-        if "mS#Sample ID" in df.columns:
+        if "Sample ID" in df.columns:
+            df = df.rename(columns={"Sample ID": "sample_id"})
+        elif "mS#Sample ID" in df.columns:
             df = df.rename(columns={"mS#Sample ID": "sample_id"})
+        elif "Sample slug" in df.columns:
+            mapping = {s.slug: s.id for s in self._samples}
+            df["sample_id"] = [mapping[value] for value in df["Sample slug"]]
+            df = df.drop(columns=["Sample slug"])
         elif "mS#Sample slug" in df.columns:
             mapping = {s.slug: s.id for s in self._samples}
             df["sample_id"] = [mapping[value] for value in df["mS#Sample slug"]]
             df = df.drop(columns=["mS#Sample slug"])
+        elif "Sample name" in df.columns or "Sample name" in df.columns:
+            mapping = {s.name: s.id for s in self._samples}
+            if len(mapping) != len(self._samples):
+                raise ValueError(
+                    "Duplicate sample names. Cannot map orange table data to other metadata"
+                )
+            df["sample_id"] = [mapping[value] for value in df["Sample name"]]
+            df = df.drop(columns=["Sample name"])
         elif "mS#Sample name" in df.columns:
             mapping = {s.name: s.id for s in self._samples}
             if len(mapping) != len(self._samples):
                 raise ValueError(
-                    "Duplicate sample names. Cannot map orange table data to other matadata"
+                    "Duplicate sample names. Cannot map orange table data to other metadata"
                 )
             df["sample_id"] = [mapping[value] for value in df["mS#Sample name"]]
             df = df.drop(columns=["mS#Sample name"])
